@@ -17,7 +17,7 @@ def get_logger(name=_DEFAULT_LOGGER_TAG):
     return logging.getLogger(name)
 
 
-def setup_logger(logger=None, verbose=False, debug=False, sock_path=_SYSLOG_SOCK):
+def setup_logger(logger=None, verbose=False, debug=False, no_syslog=False, sock_path=_SYSLOG_SOCK):
     """
     Configure the logger with the given options
     if logger is None, it will be created using get_logger()
@@ -35,22 +35,23 @@ def setup_logger(logger=None, verbose=False, debug=False, sock_path=_SYSLOG_SOCK
         logger.setLevel(logging.INFO)
     if verbose:
         logger.addHandler(logging.StreamHandler())
-    try:
-        handler = logging.handlers.SysLogHandler(sock_path)
-        handler.setFormatter(logging.Formatter(
-                '%(asctime)s %(name)s: [%(levelname)s] %(message)s',
-                '%b %e %H:%M:%S'
-                ))
-        logger.addHandler(handler)
-    except Exception as e:
-        logger.error("Cannot attach syslog handler to logging module: {0}"
-                     .format(e.strerror))
+    if not no_syslog:
+        try:
+            handler = logging.handlers.SysLogHandler(sock_path)
+            handler.setFormatter(logging.Formatter(
+                    '%(asctime)s %(name)s: [%(levelname)s] %(message)s',
+                    '%b %e %H:%M:%S'
+                    ))
+            logger.addHandler(handler)
+        except Exception as e:
+            logger.error("Cannot attach syslog handler to logging module: {0}"
+                         .format(e.strerror))
     return logger
 
 
-def setup_logging(name=_DEFAULT_LOGGER_TAG, verbose=False, debug=False):
+def setup_logging(name=_DEFAULT_LOGGER_TAG, verbose=False, debug=False, no_syslog=False):
     """
     Does the same as setup_logger instead it calls get_logger() with `name`
 
     """
-    return setup_logger(get_logger(name), verbose=verbose, debug=debug)
+    return setup_logger(get_logger(name), verbose=verbose, debug=debug, no_syslog=no_syslog)
